@@ -13,6 +13,7 @@ extensions = [
     "sphinx.ext.napoleon",
     "sphinx.ext.todo",
     "sphinx.ext.viewcode",
+    "sphinx_rtd_dark_mode",
 ]
 source_suffix = ".rst"
 master_doc = "index"
@@ -20,7 +21,7 @@ project = "PyR3"
 year = "2021"
 author = "Krzysztof Wiśniewski"
 copyright = "{0}, {1}".format(year, author)
-version = release = "0.0.0"
+version = release = "0.1.0"
 
 pygments_style = "trac"
 templates_path = ["."]
@@ -33,7 +34,9 @@ on_rtd = os.environ.get("READTHEDOCS", None) == "True"
 
 if not on_rtd:  # only set the theme if we're building docs locally
     html_theme = "sphinx_rtd_theme"
-
+html_static_path = ["_static"]
+html_logo = "_static/logo512.png"
+html_theme_options = {"logo_only": False, "display_version": True}
 html_use_smartypants = True
 html_last_updated_fmt = "%b %d, %Y"
 html_split_index = False
@@ -42,6 +45,8 @@ html_sidebars = {
 }
 html_short_title = "%s-%s" % (project, version)
 
+default_dark_mode = False
+
 napoleon_use_ivar = True
 napoleon_use_rtype = False
 napoleon_use_param = False
